@@ -1,11 +1,22 @@
 GeomText <- proto(Geom, {
-  draw <- function(., data, scales, coordinates, ...) {
+  draw <- function(., data, scales, coordinates, ..., parse = FALSE) {
+    
+    lab <- data$label
+    if (parse) {
+      lab <- parse(text = lab)
+    }
+    
     with(coordinates$transform(data, scales), 
-      textGrob(label, x, y, default.units="native", hjust=hjust, vjust=vjust, rot=angle, 
+      textGrob(lab, x, y, default.units="native", hjust=hjust, vjust=vjust, rot=angle, 
       gp=gpar(col=alpha(colour, alpha), fontsize=size * .pt)) 
     )
   }
 
+  desc_params <- list(
+    parse = "If TRUE, the labels will be parsed into expressions and displayed as described in ?plotmath"
+  )
+
+
   draw_legend <- function(., data, ...) {
     data <- aesdefaults(data, .$default_aes(), list(...))
     with(data,
@@ -23,6 +34,8 @@ GeomText <- proto(Geom, {
   default_aes <- function(.) aes(colour="black", size=5 , angle=0, hjust=0.5, vjust=0.5, alpha = 1)
   guide_geom <- function(x) "text"
   
+  
+  
   examples <- function(.) {
     p <- ggplot(mtcars, aes(x=wt, y=mpg, label=rownames(mtcars)))
     
@@ -41,6 +54,12 @@ GeomText <- proto(Geom, {
     p + geom_text(aes(size=wt))
     p + geom_text(aes(size=wt)) + scale_size(to=c(3,6))
     
+    # You can display expressions by setting parse = TRUE.  The 
+    # details of the display are described in ?plotmath, but note that
+    # geom_text uses strings, not expressions.
+    p + geom_text(aes(label = paste(wt, "^(", cyl, ")", sep = "")),
+      parse = T)
+    
     # Use qplot instead
     qplot(wt, mpg, data = mtcars, label = rownames(mtcars),
        geom=c("point", "text"))
