@@ -36,8 +36,8 @@ ggplot.data.frame <- function(data, mapping=aes(), ..., environment = globalenv(
     facet = FacetGrid$new(),
     plot_env = environment
   ), class="ggplot")
-
-  p$options$labels <- as.list(as.character(mapping))
+  
+  p$options$labels <- make_labels(mapping)
 
   set_last_plot(p)
   p
