@@ -1,6 +1,7 @@
 ScaleIdentity <- proto(ScaleDiscrete, {  
   doc <- TRUE
   common <- c("colour","fill","size","shape","linetype")
+  aliases <- "scale_color_identity"
   new <- function(., name=NULL, breaks=NULL, labels=NULL, formatter = NULL, legend = TRUE, variable="x") {
     
     b_and_l <- check_breaks_and_labels(breaks, labels)
@@ -34,14 +35,13 @@ ScaleIdentity <- proto(ScaleDiscrete, {
     # To get a legend, you also need to supply the labels to
     # be used on the legend
     qplot(1:4, 1:4, fill = colour, geom = "tile") +
-      scale_fill_identity(labels = letters[1:4], name = "trt")
+      scale_fill_identity("trt", labels = letters[1:4], breaks = colour)
     
     # cyl scaled to appropriate size
     qplot(mpg, wt, data = mtcars, size = cyl)
 
     # cyl used as point size
     qplot(mpg, wt, data = mtcars, size = cyl) + scale_size_identity()
-  
   }
   
 })
