@@ -34,10 +34,11 @@ Stat <- proto(TopLevel, expr={
     # stats[stats$ORDER, ]
     
     groups <- split(data, data$group)
-    stats <- lapply(groups, function(group) .$calculate(group, scales, ...))
+    stats <- lapply(groups, function(group) 
+      .$calculate(data = group, scales = scales, ...))
     
     stats <- mapply(function(new, old) {
-      if (is.null(new)) return(data.frame())
+      if (empty(new)) return(data.frame())
       unique <- uniquecols(old)
       missing <- !(names(unique) %in% names(new))
       cbind(
